package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.LcdInfo;
import com.ruoyi.system.domain.vo.LcdInfoVo;

import java.util.Date;
import java.util.List;

/**
 * 消息Service接口
 *
 * @author ruoyi
 * @date 2023-01-14
 */
public interface ILcdInfoService
{
    /**
     * 查询消息
     *
     * @param id 消息主键
     * @return 消息
     */
    public List<LcdInfoVo> selectLcdInfoById(Long id);

    /**
     * 查询消息列表
     *
     * @param lcdInfo 消息
     * @return 消息集合
     */
    public List<LcdInfo> selectLcdInfoList(LcdInfo lcdInfo);

    /**
     * 新增消息
     *
     * @param lcdInfovo 消息
     * @return 结果
     */
    public AjaxResult insertLcdInfo(LcdInfoVo lcdInfovo);

    public int selectUserId(LcdInfoVo lcdInfoVo);

    /**
     * 修改消息
     *
     * @param lcdInfo 消息
     * @return 结果
     */
    public int updateLcdInfo(LcdInfo lcdInfo);

    /**
     * 批量删除消息
     *
     * @param ids 需要删除的消息主键集合
     * @return 结果
     */
    public int deleteLcdInfoByIds(Long[] ids);

    /**
     * 删除消息信息
     *
     * @param id 消息主键
     * @return 结果
     */
    public int deleteLcdInfoById(Long id);
    /**
     * 搜索消息列表.
     * @param title
     * @param lcdTimeLeft
     * @param lcdTimeRight
     * @return 结果
     */
    List<LcdInfo> selectList(String title, Date lcdTimeLeft, Date lcdTimeRight);
}
